@@ -1,7 +1,7 @@
 #line 1
 use strict; use warnings;
 package Inline::C;
-our $VERSION = '0.64';
+our $VERSION = '0.67';
 
 use Inline 0.56;
 use Config;
@@ -778,7 +778,6 @@ sub write_Makefile_PL {
     my $i = 0;
     for (@{$o->{ILSM}{MAKEFILE}{TYPEMAPS}}) {
         $o->{ILSM}{xsubppargs} .= "-typemap \"$_\" ";
-        $o->{ILSM}{MAKEFILE}{TYPEMAPS}->[$i++] = fix_space($_);
     }
 
     my %options = (
@@ -957,7 +956,6 @@ sub fix_make {
             $fix = $fixes{$1}
         ) {
             my $fixed = $o->{ILSM}{$fix};
-            $fixed = fix_space($fixed) if $fix eq 'install_lib';
             print MAKEFILE "$1 = $fixed\n";
         }
         else {
@@ -1038,11 +1036,6 @@ sub quote_space {
     $_[0] = $out;
 }
 
-sub fix_space {
-    $_[0] =~ s/ /\\ /g if $_[0] =~ / /;
-    $_[0];
-}
-
 #==============================================================================
 # This routine used by C/t/09parser to test that the expected parser is in use
 #==============================================================================
